Build constants list from a compiled model spec
build_constants_from_spec.RdProduces a named list of constants to pass into nimbleModel.
Constants include core sizes (N, P, components) and
hyperparameters for priors implied by spec$plan.
build_constants_from_spec.RdProduces a named list of constants to pass into nimbleModel.
Constants include core sizes (N, P, components) and
hyperparameters for priors implied by spec$plan.