Skip to contents

Safely coerce MCMC samples to a numeric matrix

Usage

.extract_draws(
  object,
  pars = NULL,
  chains = c("stack", "first"),
  epsilon = NULL
)

Arguments

object

A mixgpd_fit.

pars

Optional character vector of parameter names to keep (exact match).

Value

Numeric matrix of draws (iter x parameters).

Details

This is the matrix-oriented companion to .get_samples_mcmclist(). It can either stack all chains or keep only the first chain, always removes stick-breaking v variables, applies the standard component truncation rule, and optionally filters to an exact set of parameter names.