| preview_site | R Documentation |
preview_site() opens your pkgdown site in your browser, served via a
local HTTP server. This enables dynamic features such as search to work
correctly in preview.
preview_site(pkg = ".", path = ".", preview = TRUE)
pkg |
Path to package. |
path |
Path relative to destination |
preview |
If |
stop_preview() to stop the server.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.