Skip to contents

Convert a list of Open Specy objects into one-spectrum objects, or split a file-backed map into lightweight region views.

Usage

split_spec(x, ...)

# Default S3 method
split_spec(x, ...)

Arguments

x

a list of OpenSpecy objects or another supported spectral object.

...

arguments passed to class methods.

Value

For ordinary inputs, a list of Open Specy objects each with one spectrum. For FileSpecs, a named list of descriptor-only FileSpecs region views that share the immutable source and cache.

Details

Function will accept a list of Open Specy objects of any length and will split them to their individual components. For example a list of two objects, an Open Specy with only one spectrum and an Open Specy with 50 spectra will return a list of length 51 each with Open Specy objects that only have one spectrum.

See also

c_spec() for combining OpenSpecy objects. collapse_spec() for summarizing OpenSpecy objects.

Author

Zacharias Steinmetz, Win Cowger

Examples

data("test_lib")
data("raman_hdpe")
listed <- list(test_lib, raman_hdpe)
test <- split_spec(listed)
test2 <- split_spec(list(test_lib))