stop_preview: Stop HTTP preview

View source: R/preview.R

stop_previewR Documentation

Stop HTTP preview

Description

Stops the HTTP server started by preview_site(), if active. This can be called manually, but is not strictly necessary as the server is automatically stopped when previewing a new site or ending the R session.

Usage

stop_preview()

pkgdown documentation built on July 8, 2026, 1:07 a.m.