Skip to contents

Summarize the posterior clustering induced by the Dahl representative partition.

Usage

# S3 method for class 'dpmixgpd_cluster_fit'
summary(
  object,
  burnin = NULL,
  thin = NULL,
  top_n = 5L,
  order_by = c("size", "label"),
  vars = NULL,
  ...
)

Arguments

object

A cluster fit.

burnin

Number of initial posterior draws to discard.

thin

Keep every thin-th posterior draw.

top_n

Number of populated clusters to profile when descriptive summaries are available.

order_by

Ordering rule for descriptive cluster profiles:

  • "size": decreasing cluster size

  • "label": ascending cluster label

vars

Optional character vector of numeric columns to summarize within each cluster.

...

Unused.

Value

Summary list with the number of retained clusters, cluster sizes, optional cluster-level descriptive summaries, and the burn-in/thinning settings used to construct the summary.

Details

This summary is based on predict.dpmixgpd_cluster_fit() with type = "label". The reported cluster count \(K^*\) is the number of unique labels in the representative partition rather than the number of components available in the truncated sampler.