Skip to contents

Summarize pairwise posterior co-clustering probabilities.

Usage

# S3 method for class 'dpmixgpd_cluster_psm'
summary(object, ...)

Arguments

object

Cluster PSM object.

...

Unused.

Value

Summary list with matrix size and basic summaries of the similarity entries.

Details

The diagonal of a posterior similarity matrix is always close to one, while off-diagonal values near one indicate highly stable co-clustering across retained posterior draws.