Generate a JSON search index from the built site. This is used by fuse.js to provide a javascript powered search for BS5 powered pkgdown sites.
NB: build_search() is called automatically by build_site(); you don't
need call it yourself. This page documents how it works and its customisation
options.
Usage
build_search(pkg = ".", override = list())YAML config
You can exclude some paths from the search index using search.exclude.
Below we exclude the changelog from the search index:
Debugging
If search is not working, run pkgdown::pkgdown_sitrep() to eliminate
common issues such as the absence of URL in the pkgdown configuration file
of your package.