Safely coerce MCMC samples to a numeric matrix
dot-extract_draws.RdSafely coerce MCMC samples to a numeric matrix
Usage
.extract_draws(
object,
pars = NULL,
chains = c("stack", "first"),
epsilon = NULL
)Details
This is the matrix-oriented companion to .get_samples_mcmclist(). It can
either stack all chains or keep only the first chain, always removes
stick-breaking v variables, applies the standard component truncation rule,
and optionally filters to an exact set of parameter names.