Extract cluster assignment matrix from MCMC samples
dot-extract_z_matrix.RdExtracts the posterior draws of cluster assignments z[1:N] from a fitted
mixgpd_fit object and returns them as an integer matrix (iterations x N).
dot-extract_z_matrix.RdExtracts the posterior draws of cluster assignments z[1:N] from a fitted
mixgpd_fit object and returns them as an integer matrix (iterations x N).