Convert a list of Open Specy objects into one-spectrum objects, or split a file-backed map into lightweight region views.
Value
For ordinary inputs, a list of Open Specy objects each with one spectrum.
For FileSpecs, a named list of descriptor-only FileSpecs region views
that share the immutable source and cache.
Details
Function will accept a list of Open Specy objects of any length and will split them to their individual components. For example a list of two objects, an Open Specy with only one spectrum and an Open Specy with 50 spectra will return a list of length 51 each with Open Specy objects that only have one spectrum.
See also
c_spec() for combining OpenSpecy objects.
collapse_spec() for summarizing OpenSpecy objects.