"

Skip to contents

Stops the HTTP server started by preview_site(), if active. This can be called manually, but is not strictly necessary as the server is automatically stopped when previewing a new site or ending the R session.

Usage

stop_preview()