| stop_preview | R Documentation |
Stops the HTTP server started by preview_site(), if active. This can be
called manually, but is not strictly necessary as the server is
automatically stopped when previewing a new site or ending the R session.
stop_preview()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.